@@ -269,17 +269,20 @@ stop_passwd (PasswordDialog *pdialog)
 	/* This is the standard way of returning from the dialog with passwd. 
 	 * If we return this way we can safely kill passwd as it has completed
 	 * its task.
-	 * 
-	 * Maybe we should run free_passwd_resources here first, and not let
-	 * our child watcher do it?
 	 */
 	
 	if (pdialog->backend_pid != -1) {
 		kill (pdialog->backend_pid, 9);
 	}
 	
-	/* Our child_watch_cb should now handle our kill signal,
-	 * run waitpid and call free_passwd_resources appropriately. */
+	/* We must run free_passwd_resources here and not let our child
+	 * watcher do it, since it will access invalid memory after the
+	 * dialog has been closed and cleaned up.
+	 * 
+	 * If we had more than a single thread we'd need to remove
+	 * the child watch before trying to kill the child.
+	 */
+	free_passwd_resources (pdialog);
 }
 
 /* Clean up passwd resources */
@@ -288,6 +291,15 @@ free_passwd_resources (PasswordDialog *pdialog)
 {
 	GError	*error = NULL;
 	
+	/* Remove the child watcher */
+	if (pdialog->backend_child_watch_id != 0) {
+		
+		g_source_remove (pdialog->backend_child_watch_id);
+
+		pdialog->backend_child_watch_id = 0;
+	}
+
+	
 	/* Close IO channels (internal file descriptors are automatically closed) */
 	if (pdialog->backend_stdin != NULL) {
 		
@@ -924,13 +936,8 @@ passdlg_process_response (PasswordDialog *pdialog, gint response_id)
 		/* Stop passwd if an error occured and it is still running */
 		if (pdialog->backend_state == PASSWD_STATE_ERR) {
 			
-			/* Stop child watcher */
-			g_source_remove (pdialog->backend_child_watch_id);
-			pdialog->backend_child_watch_id = 0;
-			
 			/* Stop passwd, free resources */
 			stop_passwd (pdialog);
-			free_passwd_resources (pdialog);
 		}
 		
 		/* Check that the backend is still running, or that an error
@@ -1093,5 +1100,6 @@ gnome_about_me_password (GtkWindow *parent)
 	stop_passwd (pdialog);
 	gtk_widget_destroy (wpassdlg);
 	g_queue_free (pdialog->backend_stdin_queue);
+	g_object_unref (dialog);
 	g_free (pdialog);
 }
