@@ -210,11 +210,13 @@ update_color_scheme_tab (const gchar *theme)
 {
 	GSList *symbolic_colors = NULL;
 	GSList *engines = NULL;
-	gboolean fg, bg, base, text, fg_s, bg_s, enable_colors;
+	gboolean fg, bg, base, text, fg_s, bg_s, enable_colors, enable_revert;
 	gchar *filename;
 	gchar *theme_name = NULL;
+	gchar *color_scheme= NULL;
 	GtkSettings *settings;
 	GladeXML *dialog;
+	GConfClient *client;
 
 	dialog = gnome_theme_manager_get_theme_dialog ();
 
@@ -233,10 +235,17 @@ update_color_scheme_tab (const gchar *theme)
 	fg_s = (g_slist_find_custom (symbolic_colors, "selected_fg_color", g_str_equal) != NULL);
 	bg_s = (g_slist_find_custom (symbolic_colors, "selected_bg_color", g_str_equal) != NULL);
 
-	enable_colors = (fg && bg && base && text && fg_s && bg_s);
+	enable_colors = enable_revert = (fg && bg && base && text && fg_s && bg_s);
+
+	client = gconf_client_get_default ();
+  	color_scheme = gconf_client_get_string (client, COLOR_SCHEME_KEY, NULL);
+	if (color_scheme == NULL || strcmp (color_scheme, "") == 0)
+		enable_revert = FALSE;
+	g_free (color_scheme);
+	g_object_unref (client);
 
 	gtk_widget_set_sensitive (WID ("color_scheme_table"), enable_colors);
-	gtk_widget_set_sensitive (WID ("color_scheme_revert_button"), enable_colors);
+	gtk_widget_set_sensitive (WID ("color_scheme_revert_button"), enable_revert);
 
 	if (enable_colors)
 		gtk_widget_hide (WID ("color_scheme_message_hbox"));
@@ -893,25 +902,24 @@ update_color_buttons_from_string (gchar *color_scheme)
   {
     color_scheme_pair = g_strsplit (current_string, ":", 0);
 
-    if (color_scheme_pair[0] == NULL)
-      continue;
+    if (color_scheme_pair[0] != NULL && color_scheme_pair[1] != NULL)
+    {
+      g_strstrip (color_scheme_pair[0]);
+      g_strstrip (color_scheme_pair[1]);
 
-    g_strstrip (color_scheme_pair[0]);
-    g_strstrip (color_scheme_pair[1]);
-
-
-    if (!strcmp ("fg_color", color_scheme_pair[0]))
-      gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[0]);
-    else if (!strcmp ("bg_color", color_scheme_pair[0]))
-      gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[1]);
-    else if (!strcmp ("text_color", color_scheme_pair[0]))
-      gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[2]);
-    else if (!strcmp ("base_color", color_scheme_pair[0]))
-      gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[3]);
-    else if (!strcmp ("selected_fg_color", color_scheme_pair[0]))
-      gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[4]);
-    else if (!strcmp ("selected_bg_color", color_scheme_pair[0]))
-      gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[5]);
+      if (!strcmp ("fg_color", color_scheme_pair[0]))
+        gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[0]);
+      else if (!strcmp ("bg_color", color_scheme_pair[0]))
+        gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[1]);
+      else if (!strcmp ("text_color", color_scheme_pair[0]))
+        gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[2]);
+      else if (!strcmp ("base_color", color_scheme_pair[0]))
+        gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[3]);
+      else if (!strcmp ("selected_fg_color", color_scheme_pair[0]))
+        gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[4]);
+      else if (!strcmp ("selected_bg_color", color_scheme_pair[0]))
+        gdk_color_parse (color_scheme_pair[1], &color_scheme_colors[5]);
+    }
 
     g_strfreev (color_scheme_pair);
   }
